@@ -14,6 +14,27 @@ class EvalTool(object):
 
         self.experiment_name = experiment_name
 
+        # Plot params configurable by user
+
+        # Plot N Results
+        self.plot_n_res_scale  = "both"
+        self.plot_n_res_ylabel = "Number of Results"
+        self.plot_n_res_xticks = True
+
+        # Plot Query times
+        self.plot_query_time_scale  = "both"
+        self.plot_query_time_ylabel = "Average Query Time(s)"
+        self.plot_query_time_xticks = True
+
+        # Plot Query Throughput
+        self.plot_query_throughput_scale  = "both"
+        self.plot_query_throughput_ylabel = "Queries per second"
+        self.plot_query_throughput_xticks = True
+
+        # Plot Results Throughput
+        self.plot_n_res_throughput_scale  = "both"
+        self.plot_n_res_throughput_xticks = True
+
         try:
             self.data = pd.read_csv(experiment_name + ".csv", index_col=0)
         except:
@@ -28,6 +49,33 @@ class EvalTool(object):
 
         self.export_to_csv()
 
+    def set_log_scale(self, val):
+
+        self.plot_n_res_scale             = val
+        self.plot_query_time_scale        = val
+        self.plot_query_throughput_scale  = val
+        self.plot_n_res_throughput_scale  = val
+
+    def set_log_scale_for_x_only(self):
+
+        self.plot_n_res_scale             = "x"
+        self.plot_query_time_scale        = "x"
+        self.plot_query_throughput_scale  = "x"
+        self.plot_n_res_throughput_scale  = "x"
+
+    def set_log_scale_for_y_only(self):
+
+        self.plot_n_res_scale             = "y"
+        self.plot_query_time_scale        = "y"
+        self.plot_query_throughput_scale  = "y"
+        self.plot_n_res_throughput_scale  = "y"
+
+    def set_xticks(self, val=True):
+        self.plot_n_res_xticks            = val
+        self.plot_query_time_xticks       = val
+        self.plot_query_throughput_xticks = val
+        self.plot_n_res_throughput_xticks = val
+
     def add_row(self, query, engine, db_size,
             n_threads,
             n_samples,
@@ -159,11 +207,26 @@ class EvalTool(object):
 
         for i in threads:
 
-            self.plot_query_time(i)
-            self.plot_query_throughput(i)
-            self.plot_results_throughput(i, result_type="Images")
-            self.plot_query_time_speedup(i)
-            self.plot_n_results(i)
+            try:
+                self.plot_query_time(i)
+            except:
+                print("Error plotting:", "plot_query_time")
+            try:
+                self.plot_query_throughput(i)
+            except:
+                print("Error plotting:", "plot_query_throughput")
+            try:
+                self.plot_results_throughput(i, result_type="Images")
+            except:
+                print("Error plotting:", "plot_results_throughput")
+            try:
+                self.plot_query_time_speedup(i)
+            except:
+                print("Error plotting:", "plot_query_time_speedup")
+            try:
+                self.plot_n_results(i)
+            except:
+                print("Error plotting:", "plot_n_results")
 
     def plot_results_throughput_parallelism_threads(self, q,
                                             result_type="results"):
@@ -381,20 +444,24 @@ class EvalTool(object):
         filename += "plot_th_" + str(n_threads) + "_results_throughput.pdf"
 
         title = "Throughput as " + result_type + " per second - Summary"
-        p.plot_lines_all(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all(queries, db_sizes, engines, values,
+                          log=self.plot_n_res_throughput_scale,
                           title=title,
                           filename=filename,
-                          ylabel=result_type + "/s")
+                          ylabel=result_type + "/s",
+                          xticks=self.plot_n_res_throughput_xticks)
 
         filename  = self.plot_folder
         filename += "plot_th_" + str(n_threads) + "_mosaic_results_throughput.pdf"
 
         # title = "Throughput for different queries"
-        p.plot_lines_all_mosaic(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all_mosaic(queries, db_sizes, engines, values,
+                          log=self.plot_n_res_throughput_scale,
                           # title=title,
                           filename=filename,
                           xlabel="Database Size",
-                          ylabel=result_type + "/s")
+                          ylabel=result_type + "/s",
+                          xticks=self.plot_n_res_throughput_xticks)
 
 
     def plot_query_throughput(self, n_threads):
@@ -429,20 +496,25 @@ class EvalTool(object):
         filename += "plot_th_" + str(n_threads) + "_queries_throughput.pdf"
 
         title = "Query Throughput (q/s) Summary"
-        p.plot_lines_all(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all(queries, db_sizes, engines, values,
+                          log=self.plot_query_throughput_scale,
                           title=title,
                           filename=filename,
-                          ylabel="Queries per second")
+                          ylabel=self.plot_query_throughput_ylabel,
+                          xticks=self.plot_query_throughput_xticks)
 
         filename  = self.plot_folder
         filename += "plot_th_" + str(n_threads) + "_mosaic_query_throughput.pdf"
 
         # title = "Query Throughput (q/s) for different queries"
-        p.plot_lines_all_mosaic(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all_mosaic(queries, db_sizes, engines, values,
+                          log=self.plot_query_throughput_scale,
                           # title=title,
                           filename=filename,
                           xlabel="Database Size",
-                          ylabel="Queries per second")
+                          ylabel=self.plot_query_throughput_ylabel,
+                          xticks=self.plot_query_throughput_xticks
+                          )
 
 
     def plot_query_time(self, n_threads):
@@ -472,20 +544,24 @@ class EvalTool(object):
         filename += "plot_th_" + str(n_threads) + "_query_times.pdf"
 
         title = "Query Execution Time(s) Summary"
-        p.plot_lines_all(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all(queries, db_sizes, engines, values,
+                          log=self.plot_query_time_scale,
                           title=title,
                           filename=filename,
-                          ylabel="Average Query Time(s)")
+                          ylabel=self.plot_query_time_ylabel,
+                          xticks=self.plot_query_time_xticks)
 
         filename  = self.plot_folder
         filename += "plot_th_" + str(n_threads) + "_mosaic_query_times.pdf"
 
         # title = "Query Execution Time(s) for different queries"
-        p.plot_lines_all_mosaic(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all_mosaic(queries, db_sizes, engines, values,
+                          log=self.plot_query_time_scale,
                           # title=title,
                           filename=filename,
                           xlabel="Database Size",
-                          ylabel="Average Query Time(s)")
+                          ylabel=self.plot_query_time_ylabel,
+                          xticks=self.plot_query_time_xticks)
 
         return
 
@@ -517,20 +593,24 @@ class EvalTool(object):
         filename += "plot_th_" + str(n_threads) + "_n_results.pdf"
 
         title = "Returned Results Summary"
-        p.plot_lines_all(queries, db_sizes, engines, values, log="both",
+        p.plot_lines_all(queries, db_sizes, engines, values,
+                          log=self.plot_n_res_scale,
                           title=title,
                           filename=filename,
-                          ylabel="Number of Results")
+                          ylabel=self.plot_n_res_ylabel,
+                          xticks=self.plot_n_res_xticks)
 
         filename  = self.plot_folder
         filename += "plot_th_" + str(n_threads) + "_mosaic_n_results.pdf"
 
         title = "Returned Results for different queries"
-        p.plot_lines_all_mosaic(queries, db_sizes, engines, values, log="x",
+        p.plot_lines_all_mosaic(queries, db_sizes, engines, values,
+                          log=self.plot_n_res_scale,
                           title=title,
                           filename=filename,
                           xlabel="Database Size",
-                          ylabel="Number of Results")
+                          ylabel=self.plot_n_res_ylabel,
+                          xticks=self.plot_n_res_xticks)
 
         return
 
